@@ -57,6 +57,8 @@ struct _GnomeAboutPrivate {
 	GtkWidget *name_label;
 	GtkWidget *comments_label;
 	GtkWidget *copyright_label;
+
+	GtkWidget *credits_dialog;
 };
 
 enum {
@@ -183,15 +185,25 @@ static void
 gnome_about_display_credits_dialog (GnomeAbout *about)
 {
 	GtkWidget *dialog, *label, *notebook, *sw;
+
+	if (about->_priv->credits_dialog != NULL) {
+		gtk_window_present (GTK_WINDOW (about->_priv->credits_dialog));
+		return;
+	}
 	
 	dialog = gtk_dialog_new_with_buttons (_("Credits"),
 					      GTK_WINDOW (about),
 					      GTK_DIALOG_DESTROY_WITH_PARENT,
 					      GTK_STOCK_OK, GTK_RESPONSE_OK,
 					      NULL);
+	about->_priv->credits_dialog = dialog;
 	gtk_window_set_default_size (GTK_WINDOW (dialog), 360, 260);
+	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
 	g_signal_connect (dialog, "response",
 			  G_CALLBACK (gtk_widget_destroy), dialog);
+	g_signal_connect (dialog, "destroy",
+			  G_CALLBACK (gtk_widget_destroyed),
+			  &(about->_priv->credits_dialog));
 
 	notebook = gtk_notebook_new ();
 	gtk_container_set_border_width (GTK_CONTAINER (notebook), 8);
@@ -207,7 +219,8 @@ gnome_about_display_credits_dialog (GnomeAbout *about)
 		gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (sw), label);
 		gtk_viewport_set_shadow_type (GTK_VIEWPORT (GTK_BIN (sw)->child), GTK_SHADOW_NONE);
 		
-		gtk_notebook_append_page (GTK_NOTEBOOK (notebook), sw, gtk_label_new (_("Written by")));
+		gtk_notebook_append_page (GTK_NOTEBOOK (notebook), sw,
+					  gtk_label_new_with_mnemonic (_("_Written by")));
 		gnome_about_update_authors_label (about, label);
 	}
 
@@ -221,7 +234,8 @@ gnome_about_display_credits_dialog (GnomeAbout *about)
 		gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (sw), label);
 		gtk_viewport_set_shadow_type (GTK_VIEWPORT (GTK_BIN (sw)->child), GTK_SHADOW_NONE);
 
-		gtk_notebook_append_page (GTK_NOTEBOOK (notebook), sw, gtk_label_new (_("Documented by")));
+		gtk_notebook_append_page (GTK_NOTEBOOK (notebook), sw,
+					  gtk_label_new_with_mnemonic (_("_Documented by")));
 		gnome_about_update_documenters_label (about, label);
 	}
 
@@ -235,7 +249,8 @@ gnome_about_display_credits_dialog (GnomeAbout *about)
 		gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (sw), label);
 		gtk_viewport_set_shadow_type (GTK_VIEWPORT (GTK_BIN (sw)->child), GTK_SHADOW_NONE);
 
-		gtk_notebook_append_page (GTK_NOTEBOOK (notebook), sw, gtk_label_new (_("Translated by")));
+		gtk_notebook_append_page (GTK_NOTEBOOK (notebook), sw,
+					  gtk_label_new_with_mnemonic (_("_Translated by")));
 		gnome_about_update_translation_information_label (about, label);
 	}
 	
@@ -292,10 +307,12 @@ gnome_about_instance_init (GnomeAbout *about)
 	gtk_dialog_set_default_response (GTK_DIALOG (about), GTK_RESPONSE_OK);
 
 	/* Add the credits button */
-	button = gtk_dialog_add_button (GTK_DIALOG (about), "_Credits", GNOME_RESPONSE_CREDITS);
+	button = gtk_dialog_add_button (GTK_DIALOG (about), _("_Credits"), GNOME_RESPONSE_CREDITS);
 	gtk_button_box_set_child_secondary (GTK_BUTTON_BOX (GTK_DIALOG (about)->action_area), button, TRUE);
 	
 	gtk_window_set_resizable (GTK_WINDOW (about), FALSE);
+
+	priv->credits_dialog = NULL;
 }
 
 static void
