@@ -107,16 +107,6 @@ static const char *strftime_date_format = "%x";
 GNOME_CLASS_BOILERPLATE(GnomeDateEdit, gnome_date_edit,
 			GtkHBox, GTK_TYPE_HBOX)
 
-static void
-grab_focus (GtkWidget *widget)
-{
-	GnomeDateEdit *gde = GNOME_DATE_EDIT (widget);
-	
-	GTK_WIDGET_CLASS (parent_class)->grab_focus (widget);
-	
-	gtk_widget_grab_focus (gde->_priv->date_entry);
-}
-
 static void
 hide_popup (GnomeDateEdit *gde)
 {
@@ -445,23 +435,41 @@ fill_time_popup (GtkWidget *widget, GnomeDateEdit *gde)
 	gtk_option_menu_set_menu (GTK_OPTION_MENU (gde->_priv->time_popup), menu);
 }
 
+static gboolean
+gnome_date_edit_mnemonic_activate (GtkWidget *widget,
+				   gboolean   group_cycling)
+{
+	gboolean handled;
+	GnomeDateEdit *gde;
+	
+	gde = GNOME_DATE_EDIT (widget);
+
+	group_cycling = group_cycling != FALSE;
+
+	if (!GTK_WIDGET_IS_SENSITIVE (gde->_priv->date_entry))
+		handled = TRUE;
+	else
+		g_signal_emit_by_name (gde->_priv->date_entry, "mnemonic_activate", group_cycling, &handled);
+
+	return handled;
+}
+
 static void
 gnome_date_edit_class_init (GnomeDateEditClass *class)
 {
-	GtkObjectClass *object_class = (GtkObjectClass *) class;
 	GtkWidgetClass *widget_class = (GtkWidgetClass *) class;
+	GtkObjectClass *object_class = (GtkObjectClass *) class;
 	GObjectClass *gobject_class = (GObjectClass *) class;
 
 	object_class = (GtkObjectClass*) class;
 
 	object_class->destroy = gnome_date_edit_destroy;
 
-	widget_class->grab_focus = grab_focus;
-	
 	gobject_class->finalize = gnome_date_edit_finalize;
 	gobject_class->get_property = gnome_date_edit_get_property;
 	gobject_class->set_property = gnome_date_edit_set_property;
 
+	widget_class->mnemonic_activate = gnome_date_edit_mnemonic_activate;
 	g_object_class_install_property (gobject_class,
 					 PROP_TIME,
 					 g_param_spec_ulong ("time",
@@ -547,8 +555,6 @@ gnome_date_edit_instance_init (GnomeDateEdit *gde)
 	gde->_priv->upper_hour = 19;
 	gde->_priv->flags = GNOME_DATE_EDIT_SHOW_TIME;
 	create_children (gde);
-
-	GTK_WIDGET_SET_FLAGS (gde, GTK_CAN_FOCUS);
 }
 
 static void
